import 'package:json_annotation/json_annotation.dart';
import 'package:weather_fetch/models/response_objects/clouds/clouds.dart';
import 'package:weather_fetch/models/response_objects/coordinate/coordinate.dart';
import 'package:weather_fetch/models/response_objects/rain/rain.dart';
import 'package:weather_fetch/models/response_objects/response_main/response_main.dart';
import 'package:weather_fetch/models/response_objects/snow/snow.dart';
import 'package:weather_fetch/models/response_objects/sys/sys.dart';
import 'package:weather_fetch/models/response_objects/weather/weather.dart';
import 'package:weather_fetch/models/response_objects/wind/wind.dart';

part 'current_weather_response.g.dart';

@JsonSerializable(explicitToJson: true)
class CurrentWeatherResponse {
  @JsonKey(name: 'coord')
  final Coordinate coordinate;
  final List<Weather> weather;
  final String base;
  final ResponseMain main;
  final int? visibility;
  final Wind wind;
  final Clouds clouds;
  final Rain? rain;
  final Snow? snow;

  @JsonKey(fromJson: _fromJson, toJson: _toJson)
  final DateTime dt;

  final Sys sys;
  final double timezone;
  final int id;
  final String name;
  final int cod;

  CurrentWeatherResponse({
    required this.dt,
    required this.coordinate,
    required this.weather,
    required this.base,
    required this.main,
    this.visibility,
    required this.wind,
    required this.clouds,
    this.rain,
    this.snow,
    required this.sys,
    required this.timezone,
    required this.id,
    required this.name,
    required this.cod,
  });

  @override
  String toString() => """
      CurrentWeatherResponse {
        id: $id,
        name: $name,

      }

    """;

  static DateTime _fromJson(int int) =>
      DateTime.fromMillisecondsSinceEpoch(int);
  static int _toJson(DateTime time) => time.millisecondsSinceEpoch;

  /// Connect the generated [_$CurrentWeatherResponseFromJson] function to the `fromJson`
  /// factory.
  factory CurrentWeatherResponse.fromJson(Map<String, dynamic> json) =>
      _$CurrentWeatherResponseFromJson(json);

  /// Connect the generated [_$CurrentWeatherResponseToJson] function to the `toJson` method.
  Map<String, dynamic> toJson() => _$CurrentWeatherResponseToJson(this);
}
