library openweather_api;

import 'dart:async';
import 'dart:convert';

import 'package:http/http.dart' as http;
import 'package:weather_fetch/models/response_objects/current_weather_response.dart';

late http.Client _httpClient;

class OpenWeather {
  late String _apiKey;

  void init(String apiKey) {
    _httpClient = http.Client();

    _apiKey = apiKey;
  }

  Future<CurrentWeatherResponse> getCurrentWeather({
    required double lat,
    required double long,
  }) async {
    Map<String, dynamic>? jsonResponse =
        await _sendRequest('weather', lat: lat, lon: long);
    return CurrentWeatherResponse.fromJson(jsonResponse!);
  }

  Future<Map<String, dynamic>?> _sendRequest(String tag,
      {double? lat, double? lon, String? cityName}) async {
    /// Build HTTP get url by passing the required parameters
    String url = _buildUrl(tag, cityName, lat, lon);

    /// Send HTTP get response with the url
    http.Response response = await _httpClient.get(Uri.parse(url));

    /// Perform error checking on response:
    /// Status code 200 means everything went well
    if (response.statusCode == 200) {
      Map<String, dynamic>? jsonBody = json.decode(response.body);
      return jsonBody;
    }

    /// The API key is invalid, the API may be down
    /// or some other unspecified error could occur.
    /// The concrete error should be clear from the HTTP response body.
    else {
      throw Exception("The API threw an exception: ${response.body}");
    }
  }

  String _buildUrl(String tag, String? cityName, double? lat, double? lon) {
    String url = 'https://api.openweathermap.org/data/2.5/' '$tag?';

    if (cityName != null) {
      url += 'q=$cityName&';
    } else {
      url += 'lat=$lat&lon=$lon&';
    }

    url += 'appid=$_apiKey&';
    // url += 'lang=${_languageCode[language]}';
    return url;
  }
}
